The YAKS project has been merged into the **zenoh** project.

**Retrieve all the YAKS features an more in the [Eclipse zenoh](http://zenoh.io) project!**

  - zenoh service: https://github.com/eclipse-zenoh/zenoh
  - Python API: https://github.com/eclipse-zenoh/zenoh-python
  - Java API: https://github.com/eclipse-zenoh/zenoh-java
  - Go API: https://github.com/eclipse-zenoh/zenoh-go
  - C API: https://github.com/eclipse-zenoh/zenoh-c
